function awdemo(tlen)
%
% AWDEMO -- demonstration script for the AlphaWavelet Toolbox.
%
%     AWDEMO(TLEN)
%     uses a signal length of TLEN.
%
%     See also: EDGEMORLET, RCWTM, IRCWTM, XYCWTM, SHOWRCWT
%
%     AlphaWavelet Toolbox Version 1.0.1
%     Copyright (C) 2010 Alphawave Research, robjohnson@alphawaveresearch.com
%     Released under GNU GPLv3 -- see Contents.m for more info.
%

%     This file is part of AlphaWavelet.
%
%     AlphaWavelet is free software: you can redistribute it and/or modify
%     it under the terms of the GNU General Public License as published by
%     the Free Software Foundation, either version 3 of the License, or (at
%     your option) any later version.
%
%     AlphaWavelet is distributed in the hope that it will be useful, but
%     WITHOUT ANY WARRANTY; without even the implied warranty of
%     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%     General Public License for more details.
%
%     You should have received a copy of the GNU General Public License
%     along with this program.  If not, see `http://www.gnu.org/licenses/'.
%
%     **************************************************************************

% Preliminaries...
if nargin<1 || isempty(tlen), tlen=100; end	% default signal length
if nargin>1, error('nargin > 1, try awdemo'); end
if rem(tlen,1)|(tlen<=0), error('TLEN must be positive integer'); end

close all, 
disp(' ')
disp('    AlphaWavelet Toolbox Version 1.0.1')
disp('    Copyright (C) 2010 Alphawave Research, robjohnson@alphawaveresearch.com')
disp('    Released under GNU GPLv3 -- see Contents.m for more info.')
disp(' ')
disp('Thank you for using the AlphaWavelet Toolbox Version 1.0.1. Its purpose')
disp('is to provide a transparent set of tools for use in power spectral density')
disp('estimation via the continuous wavelet transform. Presently, only the Morlet')
disp('basis is implemented, and the signal must be uniformly sampled without gaps.')
disp('Extensions to allow for alternate bases and gapped data are planned for')
disp('future release. Let''s get started...')
disp('hit any key to continue'), pause

disp(' ')
disp('First, let''s look at one of the analyzing wavelets. The continuous wavelet')
disp('transform as implemented by the AlphaWavelet Toolbox uses the Morlet basis')
disp('with symmetric normalization. Adaptive admissibility is an available option')
disp('but affects the frequency response of the wavelet. The cone-of-influence is')
disp('addressed through renormalization so that a truncated wavelet has a squared')
disp('norm equal to that of a whole wavelet. With a unit sample rate throughout,')
sr=1, 
disp('let''s inspect the available options for a wavelet with resolution width')
ki=4,
disp('and central frequency of 2*pi+1/4/pi')
cf=2*pi+1/4/pi, 
disp('at scale 10')
sc=10, 
disp('and without conjugation')
cj=1,
disp('by evaluating the function EDGEMORLET. Admissibility is indicated by the flag')
aa=1, 
disp('and renormalization by the flag')
rn=1, 
disp('and for the four combinations of AA and RN the real and imaginary parts of a')
disp('whole wavelet will appear in Figure 1.')
disp('[psi,tp]=edgemorlet(sc,cj,sr,ki,cf,aa,rn);')
disp('hit any key for figure'), pause
figure(1), for ak=0:1, for rk=0:1, subplot(2,2,2*ak+rk+1), 
[psi,tp]=edgemorlet(sc,cj,sr,ki,cf,ak,rk); 
plot(tp,[real(psi); imag(psi)]); ylim(.04*[-1 1]), 
text(-35,.015,['AA=' num2str(ak)]), text(-35,-.015,['RN=' num2str(rk)]), 
text(-35,-.035,['|\psi|^2/2*sc^2=' num2str((norm(psi))^2/2*sc^2)]), 
text(-35,.035,['<\psi>=' num2str(mean(psi),2)]), end, end, drawnow

disp(' ')
disp('Not much difference, eh? Now let''s offset the wavelet by 30 units right')
ot=30,
disp('and repeat the inspection.')
disp('[psi,tp]=edgemorlet(sc,cj,sr,ki,cf,aa,rn,ot);')
disp('hit any key for figure'), pause
clf, for ak=0:1, for rk=0:1, subplot(2,2,2*ak+rk+1), 
[psi,tp]=edgemorlet(sc,cj,sr,ki,cf,ak,rk,ot); 
plot(tp,[real(psi); imag(psi)]); ylim(.04*[-1 1]), 
text(-35,.015,['AA=' num2str(ak)]), text(-35,-.015,['RN=' num2str(rk)]), 
text(-35,-.035,['|\psi|^2/2*sc^2=' num2str((norm(psi))^2/2*sc^2)]), 
text(-35,.035,['<\psi>=' num2str(mean(psi),2)]), end, end, drawnow
disp(' ')
disp('Now we can see the effect of AA and RN on the mean and norm of the')
disp('wavelet. For data analysis, we suggest AA=0 so that the shape, hence')
disp('the frequency response, of the analyzing wavelet is unaffected.')
disp('hit any key to continue'), pause

disp(' ')
disp(['Next, we need a signal. Let''s assume ' num2str(tlen) ' sample points'])
disp(['tax=1:' num2str(tlen) ';']), tax=1:tlen; 
disp('and three signal components with amplitudes around unity')
a1=rand(3,1)+.5, 
disp('and periods between 5 and 60')
p1=rand(3,1).*[5; 12; 30] + [5; 12; 30], 
disp('such that SIG0=sum_k A1(k)*real(exp(i*2*pi*(TAX/P1(k)+rand)))')
sig0=0*tax; for k=1:3, sig0=sig0+a1(k)*real(exp(i*2*pi*(tax/p1(k)+rand))); end, 
nois=2*rand(1,tlen)-1; noispwr=mean(nois.^2);
disp(['then add some noise of known rms power ' num2str(noispwr,3)])
disp(['nois=2*rand(1,' num2str(tlen) ')-1; noispwr=mean(nois.^2);'])
disp('and subtract its mean value, to appear in Figure 2.')
disp(['sig1=sig0+nois; sig1=sig1-mean(sig1);'])
sig1=sig0+nois; sig1=sig1-mean(sig1);
disp('hit any key for figure'), pause
figure(2), subplot(2,1,1), plot(tax,sig1,'bx-'), 
legend('  SIG1',-1), drawnow
disp(' ')
disp('The renormalized continuous wavelet transform is calculated by calling the')
disp('function RCWTM for a range of scales starting at')
smin=2, 
disp('and ending at')
smax=2*tlen, 
disp('where a maximum scale of twice the signal duration includes the ELF')
disp('(Extremely Low Frequency) region. For our signal SIG1, we evaluate')
disp('[rcwt1,sax]=rcwtm(sig1,sr,smin,smax,[],[],ki,cf,0,1);')
disp('(may take awhile...hit any key to start)'), pause
[rcwt1,sax]=rcwtm(sig1,sr,smin,smax,[],[],ki,cf,0,1); 
disp(' ')
disp('and display its power spectral density, mean wavelet power, integrated')
disp('instant power, and phase diagram with peak normalization using SHOWRCWT.')
disp('[h,psd1,mwp1,iip1,phase1]=showrcwt(rcwt1,''peak'',[],sr,ki,sax,tax);')
disp('(may take awhile...hit any key to start)'), pause
figure(3), [h,psd1,mwp1,iip1,phase1]=showrcwt(rcwt1,'peak',[],sr,ki,sax,tax); drawnow
disp('The IIP remains close to the sum of the squared amplitudes plus twice the')
disp(['rms noise power, ' num2str(sum(a1.^2),3) '+2*' num2str(noispwr,3) '=' num2str(sum(a1.^2)+2*noispwr,3) '.'])
subplot(2,2,3), hold on, plot(xlim,sum(a1.^2)*[1 1]+2*noispwr,'k-'), 
disp(' ')
disp('The inverse transform is calculated by the function IRCWTM')
disp('ircwt1=ircwtm(rcwt1,sr,sax,ki,cf,0,1);')
disp('(may take awhile...hit any key to start)'), pause
ircwt1=ircwtm(rcwt1,sr,sax,ki,cf,0,1);
disp('and will appear in Figure 2.')
figure(2), subplot(2,1,1), plot(tax,sig1,'bx',tax,ircwt1,'r-'), 
legend('  SIG1','IRCWT1',-1), drawnow
disp('hit any key to continue'), pause

disp(' ')
disp('Now let''s consider a signal that has had a different set of noise')
disp('added to it which will appear at the bottom of Figure 2.')
nois=2*rand(1,tlen)-1; noispwr=mean(nois.^2);
sig2=sig0+nois; sig2=sig2-mean(sig2);
disp('hit any key for figure'), pause
figure(2), subplot(2,1,2), plot(tax,sig2,'g+-'), 
legend('  SIG2',-1), drawnow
disp(' ')
disp('For our signal SIG2, we evaluate')
disp('[rcwt2,sax]=rcwtm(sig2,sr,smin,smax,[],[],ki,cf,0,1);')
disp('(may take awhile...hit any key to start)'), pause
[rcwt2,sax]=rcwtm(sig2,sr,smin,smax,[],[],ki,cf,0,1); 
disp(' ')
disp('and its inverse displayed in Figure 2')
disp('ircwt2=ircwtm(rcwt2,sr,sax,ki,cf,0,1);')
disp('(may take awhile...hit any key to start)'), pause
ircwt2=ircwtm(rcwt2,sr,sax,ki,cf,0,1);
figure(2), subplot(2,1,2), plot(tax,sig2,'g+',tax,ircwt2,'r-'), 
legend('  SIG2','IRCWT2',-1), drawnow
disp(' ')
disp('and display its power spectral density, mean wavelet power, integrated')
disp('instant power, and phase diagram with peak normalization in Figure 4.')
disp('(may take awhile...hit any key to start)'), pause
figure(4), [h,psd2,mwp2,iip2,phase2]=showrcwt(rcwt2,'peak',[],sr,ki,sax,tax); drawnow
disp('The IIP remains close to the sum of the squared amplitudes plus twice the')
disp(['rms noise power, ' num2str(sum(a1.^2),3) '+2*' num2str(noispwr,3) '=' num2str(sum(a1.^2)+2*noispwr,3) '.'])
subplot(2,2,3), hold on, plot(xlim,sum(a1.^2)*[1 1]+2*noispwr,'k-'), drawnow
disp('hit any key to continue'), pause

disp(' ')
disp('The normalized wavelet cross correlation spectrum is evaluated by calling the')
disp('function XYCWTM with arguments RCWT1 and RCWT2')
disp('[xcwt,ycwt]=xycwtm(rcwt1,rcwt2,sax,[],sr,tax,[]);')
[xcwt,ycwt]=xycwtm(rcwt1,rcwt2,sax,[],sr,tax,[]);
disp(' ')
disp('and may be displayed using SHOWRCWT, to appear in Figure 5.')
disp('[h,psdx,mwpx,iipx,phasex]=showrcwt(xcwt,''peak'',[],sr,ki,sax,tax);')
disp('(may take awhile...hit any key to start)'), pause
figure(5), [h,psdx,mwpx,iipx,phasex]=showrcwt(xcwt,'peak',[],sr,ki,sax,tax); drawnow
disp(' ')
disp('The co-correlation spectrum returned in YCWT may be used to construct a')
disp('signal drawn from the common elements of SIG1 and SIG2 using IRCWTM.')
disp('ircwty=ircwtm(ycwt,sr,sax,ki,cf,0,1);')
disp('(may take awhile...hit any key to start)'), pause
ircwty=ircwtm(ycwt,sr,sax,ki,cf,0,1);
disp(' ')
disp('and will appear in Figure 6 along with the normalized signal SIG0.')
figure(6), subplot(2,1,1), plot(tax,sig1,'bx-',tax,sig2,'g+-'), legend('  SIG1','  SIG2',-1)
subplot(2,1,2), plot(tax,sig0/max(abs(sig0)),'kx',tax,ircwty/max(abs(ircwty)),'r-'), ylim([-1 1])
legend('  SIG0','IRCWTY',-1), drawnow

disp(' ')
disp('This concludes AWDEMO. Thank you again for using the AlphaWavelet Toolbox.')
